@@ -1,6 +1,6 @@
 #!/usr/bin/env python3
 """
-The standard Cartesian axes used for most ProPlot figures.
+The standard Cartesian axes used for most proplot figures.
 """
 import copy
 import inspect
@@ -14,7 +14,7 @@ from .. import scale as pscale
 from .. import ticker as pticker
 from ..config import rc
 from ..internals import ic  # noqa: F401
-from ..internals import _not_none, _pop_rc, dependencies, docstring, text, warnings
+from ..internals import _not_none, _pop_rc, dependencies, docstring, textmods, warnings
 from . import plot, shared
 
 __all__ = ['CartesianAxes']
@@ -84,7 +84,7 @@ xoffsetloc, yoffsetloc : {'left', 'right'}, optional
     `ticklabelloc` by default (if `ticklabelloc` is a single side).
 xtickdir, ytickdir, tickdir : {'out', 'in', 'inout'}
     Direction that major and minor tick marks point for the x and y axis.
-    Use `tickdir` to control both.
+    Default is :rc:`tick.dir`. Use `tickdir` to control both.
 xticklabeldir, yticklabeldir : {'in', 'out'}
     Whether to place x and y axis tick label text inside
     or outside the axes.
@@ -144,21 +144,43 @@ xwraprange, ywraprange : 2-tuple of float, optional
     through 9 to be formatted as 0, 1, 2, 0, 1, 2, 0, 1, 2, 0. See
     `~proplot.ticker.AutoFormatter` for details.
 xmargin, ymargin, margin : float, optional
-    The default margin between plotted content and the x and y axis
-    spines. Value is proportional to the width, height of the axes.
-    Use this if you want whitespace between plotted content
-    and the spines, but don't want to explicitly set `xlim` or `ylim`.
-xticklen, yticklen, ticklen : float or str, optional
-    Tick lengths for the x and y axis. Default is :rc:`ticklen`.
+    The default margin between plotted content and the x and y axis spines.
+    Value is proportional to the width, height of the axes. Use this to add
+    whitespace between plotted content and axes edges without explicitly
+    setting `xlim` or `ylim`. Use `margin` to set both at once.
+xticklen, yticklen, ticklen : unit-spec, optional
+    Major tick lengths for the x and y axis. Default is :rc:`tick.len`.
     %(units.pt)s
-    Minor tick lengths are scaled according to :rc:`tick.lenratio`.
-    Use `ticklen` and `ticklenratio` to set both at once.
+    Use `ticklen` to set both at once.
+xticklenratio, yticklenratio, ticklenratio : float, optional
+    Relative scaling of `xticklen` and `yticklen` used to determine
+    minor tick lengths. Default is :rc:`tick.lenratio`.
+    Use `ticklenratio` to set both at once.
 xlinewidth, ylinewidth, linewidth : color-spec, optional
     Line width for the x and y axis spines and major ticks.
+    Propagates to `tickwidth` unless specified otherwise.
     Use `linewidth` to set both at once.
+xtickwidth, ytickwidth, tickwidth, : unit-spec, optional
+    Major tick widths for the x ans y axis. Default is `linewidth`
+    or :rc:`tick.width` if `linewidth` was not passed.
+    %(units.pt)s
+    Use `tickwidth` to set both at once.
+xtickwidthratio, ytickwidthratio, tickwidthratio
+    Relative scaling of `xtickwidth` and `ytickwidth` used to determine
+    minor tick widths. Default is :rc:`tick.widthratio`.
+    Use `tickwidthratio` to set both at once.
 xcolor, ycolor, color : color-spec, optional
-    Color for the x and y axis spines, ticks, tick labels, and
-    axis labels. Use `color` to set both at once.
+    Color for the x and y axis spines, ticks, tick labels, and axis
+    labels. Use `color` to set both at once.
+xtickcolor, ytickcolor, tickcolor : color-spec, optional
+    Color for the x and y axis ticks. Inherits from `color` by
+    default. Use `tickcolor` to set both at once.
+xticklabelcolor, yticklabelcolor, ticklabelcolor : color-spec, optional
+    Color for the x and y tick labels. Inherits from `color` by
+    default. Use `ticklabelcolor` to set both at once.
+xlabelcolor, ylabelcolor, labelcolor : color-spec, optional
+    Color for the x and y axis labels. Inherits from `color` by
+    default. Use `labelcolor` to set both at once.
 xgridcolor, ygridcolor, gridcolor : color-spec, optional
     Color for the x and y axis major and minor gridlines.
     Use `gridcolor` to set both at once.
@@ -185,16 +207,17 @@ _shared_docstring = """
 Parameters
 ----------
 %(extra)s**kwargs
-    Passed to `CartesianAxes`. Supports all valid  `~CartesianAxes.format` keywords.
-    You can optionally omit the {x} from keywords beginning with ``{x}`` -- for
-    example ``ax.alt{x}(lim=(0, 10))`` is equivalent to ``ax.alt{x}({x}lim=(0, 10))``.
-    You can also change the default side for the axis spine, axis tick marks, axis
-    tick labels, and/or axis labels by passing ``loc`` keywords. For example,
+    Passed to `~proplot.axes.CartesianAxes`. Supports all valid
+    `~proplot.axes.CartesianAxes.format` keywords. You can optionally
+    omit the {x} from keywords beginning with ``{x}`` -- for example
+    ``ax.alt{x}(lim=(0, 10))`` is equivalent to ``ax.alt{x}({x}lim=(0, 10))``.
+    You can also change the default side for the axis spine, axis tick marks,
+    axis tick labels, and/or axis labels by passing ``loc`` keywords. For example,
     ``ax.alt{x}(loc='{x1}')`` changes the default side from {x2} to {x1}.
 
 Returns
 -------
-CartesianAxes
+proplot.axes.CartesianAxes
     The resulting axes.
 
 Note
@@ -217,8 +240,8 @@ _alt_descrip = """
 Add an axes locked to the same location with a
 distinct {x} axis.
 This is an alias and possibly more intuitive name for
-`~CartesianAxes.twin{y}`, which generates two {x} axes
-with a shared ("twin") {y} axes.
+`~proplot.axes.CartesianAxes.twin{y}`, which generates
+two {x} axes with a shared ("twin") {y} axes.
 """
 _alt_docstring = _shared_docstring % {'descrip': _alt_descrip, 'extra': ''}
 docstring._snippet_manager['axes.altx'] = _alt_docstring.format(**_shared_x_keys)
@@ -259,9 +282,15 @@ docstring._snippet_manager['axes.dualy'] = _dual_docstring.format(**_shared_y_ke
 
 class CartesianAxes(shared._SharedAxes, plot.PlotAxes):
     """
-    Axes subclass for plotting in ordinary Cartesian coordinates.
-    Adds the `~CartesianAxes.format` method and overrides several existing
-    methods.
+    Axes subclass for plotting in ordinary Cartesian coordinates. Adds the
+    `~CartesianAxes.format` method and overrides several existing methods.
+
+    Important
+    ---------
+    This is the default axes subclass. It can be specified explicitly by passing
+    ``proj='cart'``, ``proj='cartesian'``, ``proj='rect'``, or ``proj='rectilinear'``
+    to axes-creation commands like `~proplot.figure.Figure.add_axes`,
+    `~proplot.figure.Figure.add_subplot`, and `~proplot.figure.Figure.subplots`.
     """
     _name = 'cartesian'
     _name_aliases = ('cart', 'rect', 'rectilinar')  # include matplotlib name
@@ -326,7 +355,7 @@ class CartesianAxes(shared._SharedAxes, plot.PlotAxes):
         if self._sharex is not None and axis.get_visible():
             level = 3 if self._panel_sharex_group else self.figure._sharex
             if level > 0:
-                text._transfer_text(axis.label, self._sharex.xaxis.label)
+                textmods._transfer_text(axis.label, self._sharex.xaxis.label)
                 axis.label.set_visible(False)
             if level > 2:
                 # WARNING: Cannot set NullFormatter because shared axes share the
@@ -337,7 +366,7 @@ class CartesianAxes(shared._SharedAxes, plot.PlotAxes):
         if self._sharey is not None and axis.get_visible():
             level = 3 if self._panel_sharey_group else self.figure._sharey
             if level > 0:
-                text._transfer_text(axis.label, self._sharey.yaxis.label)
+                textmods._transfer_text(axis.label, self._sharey.yaxis.label)
                 axis.label.set_visible(False)
             if level > 2:
                 axis.set_tick_params(which='both', labelleft=False, labelright=False)
@@ -835,8 +864,13 @@ class CartesianAxes(shared._SharedAxes, plot.PlotAxes):
         xbounds=None, ybounds=None,
         xmargin=None, ymargin=None,
         xticklen=None, yticklen=None,
+        xticklenratio=None, yticklenratio=None,
+        xtickwidth=None, ytickwidth=None,
+        xtickwidthratio=None, ytickwidthratio=None,
         xlinewidth=None, ylinewidth=None,
         xcolor=None, ycolor=None, color=None,  # special case (see below)
+        xtickcolor=None, ytickcolor=None,
+        xticklabelcolor=None, yticklabelcolor=None,
         xlabelcolor=None, ylabelcolor=None,
         xgridcolor=None, ygridcolor=None,
         xlabel_kw=None, ylabel_kw=None,
@@ -888,15 +922,22 @@ class CartesianAxes(shared._SharedAxes, plot.PlotAxes):
             xminorlocator_kw = xminorlocator_kw or {}
             yminorlocator_kw = yminorlocator_kw or {}
 
-            # Special case: normally we rely on rc settings like 'grid', 'labelpad',
-            # etc. when x or y is not specified but bald 'color' is too vague. So
-            # we apply 'color' right here.
+            # Color keyword arguments. Inherit from 'color' when necessary
             xcolor = _not_none(xcolor, color)
             ycolor = _not_none(ycolor, color)
-            xlabelcolor = _not_none(xlabelcolor, xcolor)
-            ylabelcolor = _not_none(ylabelcolor, ycolor)
+            if 'tick.color' not in rc_kw:
+                xtickcolor = _not_none(xtickcolor, xcolor)
+                ytickcolor = _not_none(ytickcolor, ycolor)
+            if 'tick.labelcolor' not in rc_kw:
+                xticklabelcolor = _not_none(xticklabelcolor, xcolor)
+                yticklabelcolor = _not_none(yticklabelcolor, ycolor)
+            if 'label.color' not in rc_kw:
+                xlabelcolor = _not_none(xlabelcolor, xcolor)
+                ylabelcolor = _not_none(ylabelcolor, ycolor)
 
             # Flexible keyword args, declare defaults
+            xmargin = _not_none(xmargin, rc.find('axes.xmargin', context=True))
+            ymargin = _not_none(ymargin, rc.find('axes.ymargin', context=True))
             xtickdir = _not_none(xtickdir, rc.find('xtick.direction', context=True))
             ytickdir = _not_none(ytickdir, rc.find('ytick.direction', context=True))
             xformatter = _not_none(xformatter=xformatter, xticklabels=xticklabels)
@@ -936,8 +977,11 @@ class CartesianAxes(shared._SharedAxes, plot.PlotAxes):
             for (
                 x, label,
                 labelpad, ticklabelpad,
-                color, gridcolor, labelcolor,
-                ticklen, linewidth,
+                color, linewidth,
+                gridcolor, labelcolor,
+                tickcolor, ticklabelcolor,
+                ticklen, ticklenratio,
+                tickwidth, tickwidthratio,
                 margin, bounds,
                 tickloc, spineloc,
                 ticklabelloc, labelloc,
@@ -956,8 +1000,11 @@ class CartesianAxes(shared._SharedAxes, plot.PlotAxes):
             ) in zip(
                 ('x', 'y'), (xlabel, ylabel),
                 (xlabelpad, ylabelpad), (xticklabelpad, yticklabelpad),
-                (xcolor, ycolor), (xgridcolor, ygridcolor), (xlabelcolor, ylabelcolor),
-                (xticklen, yticklen), (xlinewidth, ylinewidth),
+                (xcolor, ycolor), (xlinewidth, ylinewidth),
+                (xgridcolor, ygridcolor), (xlabelcolor, ylabelcolor),
+                (xtickcolor, ytickcolor), (xticklabelcolor, yticklabelcolor),
+                (xticklen, yticklen), (xticklenratio, yticklenratio),
+                (xtickwidth, ytickwidth), (xtickwidthratio, ytickwidthratio),
                 (xmargin, ymargin), (xbounds, ybounds),
                 (xtickloc, ytickloc), (xspineloc, yspineloc),
                 (xticklabelloc, yticklabelloc), (xlabelloc, ylabelloc),
@@ -995,8 +1042,13 @@ class CartesianAxes(shared._SharedAxes, plot.PlotAxes):
                 # Axis spine settings
                 # NOTE: This sets spine-specific color and linewidth settings. For
                 # non-specific settings _update_background is called in Axes.format()
-                self._update_spines(x, loc=spineloc, bounds=bounds)
-                self._update_background(x, edgecolor=color, linewidth=linewidth)
+                self._update_spines(
+                    x, loc=spineloc, bounds=bounds
+                )
+                self._update_background(
+                    x, edgecolor=color, linewidth=linewidth,
+                    tickwidth=tickwidth, tickwidthratio=tickwidthratio,
+                )
 
                 # Axis tick settings
                 self._update_locs(
@@ -1008,9 +1060,9 @@ class CartesianAxes(shared._SharedAxes, plot.PlotAxes):
                 )
                 self._update_ticks(
                     x, grid=grid, gridminor=gridminor,
-                    ticklen=ticklen, tickcolor=color, gridcolor=gridcolor,
-                    tickdir=tickdir, ticklabeldir=ticklabeldir,
-                    labelpad=ticklabelpad,
+                    ticklen=ticklen, ticklenratio=ticklenratio,
+                    tickdir=tickdir, labeldir=ticklabeldir, labelpad=ticklabelpad,
+                    tickcolor=tickcolor, gridcolor=gridcolor, labelcolor=ticklabelcolor,
                 )
 
                 # Axis label settings
