@@ -88,24 +88,23 @@ latmax : float, optional
     Default is ``80``.
 labels : bool, optional
     Sets `lonlabels` and `latlabels` to ``True``. Default is :rc:`grid.labels`.
-lonlabels, latlabels
+lonlabels, latlabels : optional
     Whether to label longitudes and latitudes, and on which sides
     of the map. There are four different options:
 
     1. Boolean ``True``. Indicates the left side for latitudes,
-        bottom side for longitudes.
+       bottom side for longitudes.
     2. A string or tuple of strings indicating the side names, e.g.
-        ``'left'`` for latitudes or ``'bottom'`` for longitudes.
+       ``'left'`` for latitudes or ``'bottom'`` for longitudes.
     3. A string indicating the side names with single characters, e.g.
-        ``'lr'`` for latitudes or ``'bt'`` for longitudes.
+       ``'lr'`` for latitudes or ``'bt'`` for longitudes.
     4. A boolean 2-tuple indicating whether to draw labels on the
-        ``(left, right)`` sides for latitudes, or ``(bottom, top)``
-        sides for longitudes.
+       ``(left, right)`` sides for latitudes, or ``(bottom, top)``
+       sides for longitudes.
     5. A boolean 4-tuple indicating whether to draw labels on the
-        ``(left, right, bottom, top)`` sides, as with the basemap
-        `~mpl_toolkits.basemap.Basemap.drawmeridians` and
-        `~mpl_toolkits.basemap.Basemap.drawparallels` `labels`
-        keyword.
+       ``(left, right, bottom, top)`` sides, as with the basemap
+       `~mpl_toolkits.basemap.Basemap.drawmeridians` and
+       `~mpl_toolkits.basemap.Basemap.drawparallels` `labels` keyword.
 
 lonformatter, latformatter : formatter-spec, optional
     Formatter used to style longitude and latitude gridline labels.
@@ -156,12 +155,17 @@ land, ocean, coast, rivers, lakes, borders, innerborders : bool, optional
     The style can be modified using additional `rc` settings.
 
     For example, to change :rcraw:`land.color`, use
-    ``ax.format(landcolor='green')``, and to change :rcraw:`land.zorder`,
-    use ``ax.format(landzorder=4)``.
+    ``ax.format(landcolor='green')``, and to change
+    :rcraw:`land.zorder`, use ``ax.format(landzorder=4)``.
 reso : {'lo', 'med', 'hi', 'x-hi', 'xx-hi'}, optional
     *For cartopy axes only.*
     The resolution of geographic features. For basemap axes, this must
     be passed to `~proplot.constructor.Proj`.
+color : color-spec, optional
+    Color for the axes edge. Propagates to `gridlabelcolor` unless
+    specified otherwise (similar to `proplot.axes.CartesianAxes.format`).
+gridlabelcolor : color-spec, optional
+    Color for the grid labels. Inherits from `color` by default.
 """
 docstring._snippet_manager['geo.format'] = _format_docstring
 
@@ -374,6 +378,15 @@ class GeoAxes(plot.PlotAxes):
     """
     Axes subclass for plotting in geographic projections. Uses either cartopy
     or basemap as a "backend".
+
+    Important
+    ---------
+    This axes subclass can be used by passing ``proj='proj_name'``
+    to axes-creation commands like `~proplot.figure.Figure.add_axes`,
+    `~proplot.figure.Figure.add_subplot`, and `~proplot.figure.Figure.subplots`,
+    where ``proj_name`` is a registered :ref:`PROJ projection name <proj_table>`.
+    You can also pass a `cartopy.crs.Projection` or `~mpl_toolkits.basemap.Basemap`
+    instance instead of a projection name.
     """
     @docstring._snippet_manager
     def __init__(self, *args, **kwargs):
@@ -549,6 +562,8 @@ class GeoAxes(plot.PlotAxes):
 
         # Initiate context block
         rc_kw, rc_mode = _pop_rc(kwargs)
+        if 'color' in kwargs and 'grid.labelcolor' not in rc_kw:
+            rc_kw['grid.labelcolor'] = kwargs['color']
         with rc.context(rc_kw, mode=rc_mode):
             # Label toggles
             labels = _not_none(labels, rc.find('grid.labels', context=True))
@@ -756,7 +771,7 @@ class _CartopyAxes(GeoAxes, _GeoAxes):
 
     def _init_gridlines(self):
         """
-        Create monkey patched "major" and "minor" gridliners managed by ProPlot.
+        Create monkey patched "major" and "minor" gridliners managed by proplot.
         """
         # Cartopy 0.18 monkey patch. This fixes issue where we get overlapping
         # gridlines on dateline. See the "nx -= 1" line in Gridliner._draw_gridliner
