@@ -1,6 +1,6 @@
 #!/usr/bin/env python3
 """
-The figure class used for all ProPlot figures.
+The figure class used for all proplot figures.
 """
 import functools
 import inspect
@@ -28,7 +28,7 @@ from .internals import (
     context,
     dependencies,
     docstring,
-    text,
+    textmods,
     warnings,
 )
 from .utils import units
@@ -267,7 +267,7 @@ Parameters
     * Three positional arguments specifying the number of rows, number of
       columns, and gridspec number (int) or number range (2-tuple of int).
     * A `~matplotlib.gridspec.SubplotSpec` instance generated by indexing
-      a ProPlot `~proplot.gridspec.GridSpec`.
+      a proplot `~proplot.gridspec.GridSpec`.
 
     For integer input, the implied geometry must be compatible with the implied
     geometry from previous calls -- for example, ``fig.add_subplot(331)`` followed
@@ -468,7 +468,7 @@ class Figure(mfigure.Figure):
         'pplt.units() and floats interpreted as font size-widths.'
     )
     _tight_message = (
-        'ProPlot uses its own tight layout algorithm that is activated by default. '
+        'Proplot uses its own tight layout algorithm that is activated by default. '
         "To disable it, set pplt.rc['subplots.tight'] to False or pass tight=False "
         'to pplt.subplots(). For details, see fig.auto_layout().'
     )
@@ -581,7 +581,7 @@ class Figure(mfigure.Figure):
             if self._warn_interactive:
                 Figure._warn_interactive = False  # set class attribute
                 warnings._warn_proplot(
-                    'Auto-sized ProPlot figures are not compatible with interactive '
+                    'Auto-sized proplot figures are not compatible with interactive '
                     "backends like '%matplotlib widget' and '%matplotlib notebook'. "
                     f'Reverting to the figure size ({figwidth}, {figheight}). To make '
                     'auto-sized figures, please consider using the non-interactive '
@@ -744,7 +744,7 @@ class Figure(mfigure.Figure):
         if isinstance(self, paxes.Axes):
             proj = self._name
         elif isinstance(self, maxes.Axes):
-            raise ValueError('Matplotlib axes cannot be added to ProPlot figures.')
+            raise ValueError('Matplotlib axes cannot be added to proplot figures.')
 
         # Search axes projections
         if not isinstance(proj, str):
@@ -1007,7 +1007,7 @@ class Figure(mfigure.Figure):
         # Copy text from central label to spanning label
         # NOTE: Must use spaces rather than newlines, otherwise tight layout
         # won't make room. Reason is Text implementation (see Text._get_layout())
-        text._transfer_text(axis.label, label)  # text, color, and font properties
+        textmods._transfer_text(axis.label, label)  # text, color, and font properties
         space = '\n'.join(' ' * (1 + label.get_text().count('\n')))
         for axis in axislist:  # should include original 'axis'
             axis.label.set_text(space)
@@ -1269,7 +1269,7 @@ class Figure(mfigure.Figure):
             if not kw:
                 continue
             warnings._warn_proplot(
-                f'{key!r} is not necessary in ProPlot. Pass the '
+                f'{key!r} is not necessary in proplot. Pass the '
                 'parameters as keyword arguments instead.'
             )
             kwargs.update(kw or {})
@@ -1548,7 +1548,7 @@ class Figure(mfigure.Figure):
         # Helpful warning
         if kwargs.pop('use_gridspec', None) is not None:
             warnings._warn_proplot(
-                "Ignoring the 'use_gridspec' keyword. ProPlot always allocates "
+                "Ignoring the 'use_gridspec' keyword. Proplot always allocates "
                 'additional space for colorbars using the figure gridspec '
                 "rather than 'stealing space' from the parent subplot."
             )
@@ -1816,7 +1816,7 @@ for _attr, _msg in (
         continue
     @functools.wraps(_func)  # noqa: E301
     def _disable_method(self, *args, func=_func, message=_msg, **kwargs):
-        message = f'fig.{func.__name__}() has no effect on ProPlot figures. ' + message
+        message = f'fig.{func.__name__}() has no effect on proplot figures. ' + message
         if self._is_authorized:
             return func(self, *args, **kwargs)
         else:
