@@ -1,6 +1,6 @@
 #!/usr/bin/env python3
 """
-The gridspec and subplot grid classes used throughout ProPlot.
+The gridspec and subplot grid classes used throughout proplot.
 """
 import functools
 import inspect
@@ -33,17 +33,17 @@ _shared_docstring = """
 left, right, top, bottom : unit-spec, optional
     The fixed space between the subplots and the figure edge. Default is ``None``.
     %(units.em)s
-    If ``None``, the space is determined automatically based on the font size and
-    axis sharing settings. If :rcraw:`subplots.tight` is ``True``, the space is
-    determined by the tight layout algorithm.
+    If ``None``, the space is determined automatically based on the tick and
+    label settings. If :rcraw:`subplots.tight` is ``True`` or ``tight=True`` was
+    passed to the figure, the space is determined by the tight layout algorithm.
 """
 _scalar_docstring = """
 wspace, hspace, space : unit-spec, optional
     The fixed space between grid columns, rows, or both. Default is ``None``.
     %(units.em)s
-    If ``None``, the space is determined automatically based on the font size and
-    axis sharing settings. If :rcraw:`subplots.tight` is ``True``, the space is
-    determined by the tight layout algorithm.
+    If ``None``, the space is determined automatically based on the font size and axis
+    sharing settings. If :rcraw:`subplots.tight` is ``True`` or ``tight=True`` was
+    passed to the figure, the space is determined by the tight layout algorithm.
 """
 _vector_docstring = """
 wspace, hspace, space : unit-spec or sequence, optional
@@ -54,9 +54,9 @@ wspace, hspace, space : unit-spec or sequence, optional
     %(units.em)s
 
     For elements equal to ``None``, the space is determined automatically based
-    on the font and tick settings. If :rcraw:`subplots.tight` is ``True``, the
-    space is determined by the tight layout algorithm. Otherwise, a sensible default
-    value is chosen. For example, ``subplots(ncols=3, tight=True, wspace=(2, None))``
+    on the tick and label settings. If :rcraw:`subplots.tight` is ``True`` or
+    ``tight=True`` was passed to the figure, the space is determined by the tight
+    layout algorithm. For example, ``subplots(ncols=3, tight=True, wspace=(2, None))``
     fixes the space between columns 1 and 2 but lets the tight layout algorithm
     determine the space between columns 2 and 3.
 wratios, hratios : float or sequence, optional
@@ -64,21 +64,22 @@ wratios, hratios : float or sequence, optional
     ratios for the subplot grid. Length of `wratios` must match the number
     of rows, and length of `hratios` must match the number of columns.
 width_ratios, height_ratios
-    Aliases for `wratios`, `hratios`. Included for consistency with
-    the `matplotlib.pyplot.subplots` command.
+    Aliases for `wratios`, `hratios`. Included for
+    consistency with `matplotlib.gridspec.GridSpec`.
 wpad, hpad, pad : unit-spec or sequence, optional
-    The tight layout padding between columns, rows, and both, respectively. Unlike
-    ``space``, these control the padding between subplot content (including text,
-    ticks, etc.) rather than subplot edges. As with ``space``, these can be scalars
-    or arrays optionally containing ``None``. Default is `innerpad`.
+    The tight layout padding between columns, rows, and both, respectively.
+    Unlike ``space``, these control the padding between subplot content
+    (including text, ticks, etc.) rather than subplot edges. As with
+    ``space``, these can be scalars or arrays optionally containing ``None``.
+    For elements equal to ``None``, the default is `innerpad`.
     %(units.em)s
 """
 _tight_docstring = """
 wequal, hequal, equal :  bool, optional
-    Whether to make the tight layout algorithm apply equal spacing between columns,
-    rows, or both. Default is ``False``. Ignored if :rcraw:`tight` is ``False``.
+    Whether to make the tight layout algorithm apply equal spacing
+    between columns, rows, or both. Default is ``False``.
 outerpad : unit-spec, optional
-    The tight layout padding around the left, right, top, and bottom edges
+    The scalar tight layout padding around the left, right, top, and bottom edges
     of the figure.  Default is :rc:`subplots.outerpad`.
     %(units.em)s
 innerpad : unit-spec, optional
@@ -86,8 +87,8 @@ innerpad : unit-spec, optional
     `pad`. Default is :rc:`subplots.innerpad`.
     %(units.em)s
 panelpad : unit-spec, optional
-    The tight layout padding between subplots and axes panels and between "stacked"
-    panels. Default is :rc:`subplots.panelpad`.
+    The scalar tight layout padding between subplots and their panels, colorbars, and
+    legends and between "stacks" of these objects. Default is :rc:`subplots.panelpad`.
     %(units.em)s
 """
 docstring._snippet_manager['gridspec.shared'] = _shared_docstring
@@ -101,7 +102,7 @@ def _disable_method(attr):
     Disable the inherited method.
     """
     def _dummy_method(*args):
-        raise AttributeError(f'Method {attr}() is disabled on ProPlot gridspecs.')
+        raise AttributeError(f'Method {attr}() is disabled on proplot gridspecs.')
     _dummy_method.__name__ = attr
     return _dummy_method
 
@@ -219,6 +220,15 @@ class GridSpec(mgridspec.GridSpec):
         %(gridspec.vector)s
         %(gridspec.tight)s
 
+        See also
+        --------
+        proplot.ui.figure
+        proplot.figure.Figure
+        proplot.ui.subplots
+        proplot.figure.Figure.subplots
+        proplot.figure.Figure.add_subplots
+        matplotlib.gridspec.GridSpec
+
         Note
         ----
         Adding axes panels, axes or figure colorbars, and axes or figure legends
@@ -288,7 +298,7 @@ class GridSpec(mgridspec.GridSpec):
         """
         Get a `~matplotlib.gridspec.SubplotSpec`. Slots allocated for axes panels,
         colorbars, and legends are ignored. For example, given a gridspec with 3
-        subplot rows, 3 subplot columns, 6 panel rows, and 6 panel columns, calling
+        subplot rows, 3 subplot columns, and 3 "bottom" panel rows, calling
         ``gs[1, 1]`` returns a `~matplotlib.gridspec.SubplotSpec` corresponding to
         the second *subplot* row and column rather than a *panel* row or column.
         """
@@ -1108,7 +1118,7 @@ class GridSpec(mgridspec.GridSpec):
     def figure(self, fig):
         from .figure import Figure
         if not isinstance(fig, Figure):
-            raise ValueError('Figure must be a ProPlot figure.')
+            raise ValueError('Figure must be a proplot figure.')
         self._figure = fig
         self._update_params(**fig._gridspec_params)
         fig._gridspec_params.clear()
@@ -1199,8 +1209,9 @@ class SubplotGrid(MutableSequence, list):
 
         See also
         --------
-        proplot.figure.Figure.subplots
         proplot.ui.subplots
+        proplot.figure.Figure.subplots
+        proplot.figure.Figure.add_subplots
         """
         n = kwargs.pop('n', None)
         order = kwargs.pop('order', None)
@@ -1347,7 +1358,7 @@ class SubplotGrid(MutableSequence, list):
         """
         gridspec = None
         message = (
-            'SubplotGrid can only be filled with ProPlot subplots '
+            'SubplotGrid can only be filled with proplot subplots '
             'belonging to the same GridSpec. Instead got {!r}.'
         )
         items = np.atleast_1d(items)
@@ -1368,7 +1379,7 @@ class SubplotGrid(MutableSequence, list):
         elif items.size == 1:
             items = items.flat[0]
         else:
-            raise ValueError('Input must be a single ProPlot axes.')
+            raise ValueError('Input must be a single proplot axes.')
         return items
 
     @docstring._snippet_manager
