@@ -15,6 +15,7 @@ from matplotlib import rcParamsDefault as _rc_matplotlib_native
 from matplotlib.colors import Colormap
 from matplotlib.font_manager import font_scalings
 
+from . import ic  # noqa: F401
 from . import dependencies, warnings
 
 # Regex for "probable" unregistered named colors. Try to retain warning message for
@@ -40,7 +41,7 @@ DIVERGING = 'div'
 FRAMEALPHA = 0.8  # legend and colorbar
 FONTNAME = 'sans-serif'
 FONTSIZE = 9.0
-GRIDALPHA = 0.11
+GRIDALPHA = 0.1
 GRIDBELOW = 'line'
 GRIDPAD = 4.0
 GRIDRATIO = 0.5  # differentiated from major by half size reduction
@@ -406,7 +407,7 @@ class _RcParams(MutableMapping, dict):
         return dict.__len__(self)
 
     def __iter__(self):
-        # NOTE: ProPlot doesn't add deprecated args to dictionary so
+        # NOTE: Proplot doesn't add deprecated args to dictionary so
         # we don't have to suppress warning messages here.
         yield from sorted(dict.__iter__(self))
 
@@ -507,7 +508,7 @@ else:
                 _validate[_key] = _validate_or_none(_validator_replace)
 
 
-# ProPlot overrides of matplotlib default style
+# Proplot overrides of matplotlib default style
 # WARNING: Critical to include every parameter here that can be changed by a
 # "meta" setting so that _get_default_param returns the value imposed by *proplot*
 # and so that "changed" settings detected by Configurator.save are correct.
@@ -775,8 +776,8 @@ _rc_proplot_table = {
 
     # Axes additions
     'axes.alpha': (
-        1.0,
-        _validate_float,
+        None,
+        _validate_or_none(_validate_float),
         'Opacity of the background axes patch.'
     ),
     'axes.inbounds': (
@@ -804,15 +805,20 @@ _rc_proplot_table = {
         _validate_bool,
         'Toggles country border lines on and off.'
     ),
+    'borders.alpha': (
+        None,
+        _validate_or_none(_validate_float),
+        'Opacity for country border lines.',
+    ),
     'borders.color': (
         BLACK,
         _validate_color,
-        'Line color for country borders.'
+        'Line color for country border lines.'
     ),
     'borders.linewidth': (
         LINEWIDTH,
         _validate_pt,
-        'Line width for country borders.'
+        'Line width for country border lines.'
     ),
     'borders.zorder': (
         ZLINES,
@@ -868,6 +874,11 @@ _rc_proplot_table = {
         _validate_bool,
         'Toggles coastline lines on and off.'
     ),
+    'coast.alpha': (
+        None,
+        _validate_or_none(_validate_float),
+        'Opacity for coast lines',
+    ),
     'coast.color': (
         BLACK,
         _validate_color,
@@ -878,6 +889,11 @@ _rc_proplot_table = {
         _validate_pt,
         'Line width for coast lines.'
     ),
+    'coast.zorder': (
+        ZLINES,
+        _validate_float,
+        'Z-order for coast lines.'
+    ),
 
     # Colorbars
     'colorbar.edgecolor': (
@@ -1224,7 +1240,7 @@ _rc_proplot_table = {
     'gridminor.alpha': (
         GRIDALPHA,
         _validate_float,
-        'Minor gridline transparency.'
+        'Minor gridline opacity.'
     ),
     'gridminor.color': (
         BLACK,
@@ -1267,20 +1283,25 @@ _rc_proplot_table = {
         'Toggles internal political border lines (e.g. states and provinces) '
         'on and off.'
     ),
+    'innerborders.alpha': (
+        None,
+        _validate_or_none(_validate_float),
+        'Opacity for internal political border lines',
+    ),
     'innerborders.color': (
         BLACK,
         _validate_color,
-        'Line color for internal political borders.'
+        'Line color for internal political border lines.'
     ),
     'innerborders.linewidth': (
         LINEWIDTH,
         _validate_pt,
-        'Line width for internal political borders.'
+        'Line width for internal political border lines.'
     ),
     'innerborders.zorder': (
         ZLINES,
         _validate_float,
-        'Z-order for internal border lines.'
+        'Z-order for internal political border lines.'
     ),
 
     # Axis label settings
@@ -1312,6 +1333,11 @@ _rc_proplot_table = {
         _validate_bool,
         'Toggles lake patches on and off.'
     ),
+    'lakes.alpha': (
+        None,
+        _validate_or_none(_validate_float),
+        'Opacity for lake patches',
+    ),
     'lakes.color': (
         WHITE,
         _validate_color,
@@ -1329,6 +1355,11 @@ _rc_proplot_table = {
         _validate_bool,
         'Toggles land patches on and off.'
     ),
+    'land.alpha': (
+        None,
+        _validate_or_none(_validate_float),
+        'Opacity for land patches',
+    ),
     'land.color': (
         BLACK,
         _validate_color,
@@ -1418,6 +1449,11 @@ _rc_proplot_table = {
         _validate_bool,
         'Toggles ocean patches on and off.'
     ),
+    'ocean.alpha': (
+        None,
+        _validate_or_none(_validate_float),
+        'Opacity for ocean patches',
+    ),
     'ocean.color': (
         WHITE,
         _validate_color,
@@ -1471,6 +1507,11 @@ _rc_proplot_table = {
         _validate_bool,
         'Toggles river lines on and off.'
     ),
+    'rivers.alpha': (
+        None,
+        _validate_or_none(_validate_float),
+        'Opacity for river lines.',
+    ),
     'rivers.color': (
         BLACK,
         _validate_color,
